==> xnu-2422.115.4.tar.gz: xnu-2422.115.4/bsd/netinet/mptcp_timer.h <==
/*
 * Copyright (c) 2012 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _NETINET_MPTCP_TIMER_H_
#define	_NETINET_MPTCP_TIMER_H_

#ifdef BSD_KERNEL_PRIVATE

#define	MPT_REXMT	0	/* retransmit */
#define	MPT_TIMEWAIT	1	/* timewait timer */

__BEGIN_DECLS
extern uint32_t mptcp_timer(struct mppcbinfo *);
extern void mptcp_start_timer(struct mptcb *, int);
extern void mptcp_cancel_timer(struct mptcb *, int);
extern void mptcp_cancel_all_timers(struct mptcb *);
__END_DECLS

#endif /* BSD_KERNEL_PRIVATE */
#endif /* !_NETINET_MPTCP_TIMER_H_ */

==> xnu-6153.141.1.tar.gz: xnu-6153.141.1/bsd/netinet/mptcp_timer.h <==
/*
 * Copyright (c) 2012-2017 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _NETINET_MPTCP_TIMER_H_
#define _NETINET_MPTCP_TIMER_H_

#ifdef BSD_KERNEL_PRIVATE

#define MPT_REXMT       0       /* retransmit */
#define MPT_TIMEWAIT    1       /* timewait timer */

__BEGIN_DECLS
extern uint32_t mptcp_timer(struct mppcbinfo *mppi);
extern void mptcp_start_timer(struct mptses *mpte, int timer_type);
extern void mptcp_cancel_timer(struct mptcb *mp_tp, int timer_type);
extern void mptcp_cancel_all_timers(struct mptcb *mp_tp);
extern void mptcp_init_urgency_timer(struct mptses *mpte);
extern void mptcp_set_urgency_timer(struct mptses *mpte);
__END_DECLS

#endif /* BSD_KERNEL_PRIVATE */
#endif /* !_NETINET_MPTCP_TIMER_H_ */
